@@ -228,25 +228,25 @@ fn display() {
 
 #[test]
 fn to_array() {
-    let vec2 = Vector2::new(1, 2);
-    let vec3 = Vector3::new(1, 2, 3);
-    let vec4 = Vector4::new(1, 2, 3, 4);
+    let arr2 = Vector2::new(1, 2).to_array();
+    let arr3 = Vector3::new(1, 2, 3).to_array();
+    let arr4 = Vector4::new(1, 2, 3, 4).to_array();
 
-    assert_eq!(vec2.to_array(), [1, 2]);
-    assert_eq!(vec3.to_array(), [1, 2, 3]);
-    assert_eq!(vec4.to_array(), [1, 2, 3, 4]);
+    assert_eq!(arr2, [1, 2]);
+    assert_eq!(arr3, [1, 2, 3]);
+    assert_eq!(arr4, [1, 2, 3, 4]);
 }
 
 
 #[test]
 fn to_vec() {
-    let vec2 = Vector2::new(1, 2);
-    let vec3 = Vector3::new(1, 2, 3);
-    let vec4 = Vector4::new(1, 2, 3, 4);
+    let vec2 = Vector2::new(1, 2).to_vec();
+    let vec3 = Vector3::new(1, 2, 3).to_vec();
+    let vec4 = Vector4::new(1, 2, 3, 4).to_vec();
 
-    assert_eq!(vec2.to_vec(), vec![1, 2]);
-    assert_eq!(vec3.to_vec(), vec![1, 2, 3]);
-    assert_eq!(vec4.to_vec(), vec![1, 2, 3, 4]);
+    assert_eq!(vec2, vec![1, 2]);
+    assert_eq!(vec3, vec![1, 2, 3]);
+    assert_eq!(vec4, vec![1, 2, 3, 4]);
 }
 
 
@@ -260,13 +260,51 @@ fn iterator() {
     let mut sum_of_vec3 = 0;
     let mut sum_of_vec4 = 0;
     
-    for i in vec2 { sum_of_vec2 += i; }
-    for i in vec3 { sum_of_vec3 += i; }
-    for i in vec4 { sum_of_vec4 += i; }
+    for i in vec2.into_iter() { sum_of_vec2 += i; }
+    for i in vec3.into_iter() { sum_of_vec3 += i; }
+    for i in vec4.into_iter() { sum_of_vec4 += i; }
 
     assert_eq!(sum_of_vec2, 3);
     assert_eq!(sum_of_vec3, 6);
     assert_eq!(sum_of_vec4, 10);
+
+    let mut iter2 = vec2.into_iter();
+    let mut iter3 = vec3.into_iter();
+    let mut iter4 = vec4.into_iter();
+
+    assert_eq!(iter2.next(), Some(1));
+    assert_eq!(iter2.next(), Some(2));
+    assert_eq!(iter2.next(), None);
+
+    assert_eq!(iter3.next(), Some(1));
+    assert_eq!(iter3.next(), Some(2));
+    assert_eq!(iter3.next(), Some(3));
+    assert_eq!(iter3.next(), None);
+
+    assert_eq!(iter4.next(), Some(1));
+    assert_eq!(iter4.next(), Some(2));
+    assert_eq!(iter4.next(), Some(3));
+    assert_eq!(iter4.next(), Some(4));
+    assert_eq!(iter4.next(), None);
+
+    let mut iter2 = vec2.into_iter();
+    let mut iter3 = vec3.into_iter();
+    let mut iter4 = vec4.into_iter();
+
+    assert_eq!(iter2.next_back(), Some(2));
+    assert_eq!(iter2.next_back(), Some(1));
+    assert_eq!(iter2.next_back(), None);
+
+    assert_eq!(iter3.next_back(), Some(3));
+    assert_eq!(iter3.next_back(), Some(2));
+    assert_eq!(iter3.next_back(), Some(1));
+    assert_eq!(iter3.next_back(), None);
+
+    assert_eq!(iter4.next_back(), Some(4));
+    assert_eq!(iter4.next_back(), Some(3));
+    assert_eq!(iter4.next_back(), Some(2));
+    assert_eq!(iter4.next_back(), Some(1));
+    assert_eq!(iter4.next_back(), None);
 }
 
 
